﻿using Newtonsoft.Json;

namespace EVCB_OCPP.Packet20.DataTypes.EnumTypes
{
    public enum ConnectorEnumType
    {
        /// <summary>
        ///  Combined Charging System 1 (captive cabled) a.k.a. Combo 1
        /// </summary>
        cCCS1 = 1,
        /// <summary>
        ///  Combined Charging System 2 (captive cabled) a.k.a. Combo 2
        /// </summary>
        cCCS2,
        /// <summary>
        ///  JARI G105-1993 (captive cabled) a.k.a. CHAdeMO
        /// </summary>
        cG105,
        /// <summary>
        ///  Tesla Connector (captive cabled)
        /// </summary>
        cTesla,
        /// <summary>
        ///  IEC62196-2 Type 1 connector (captive cabled) a.k.a. J1772
        /// </summary>
        cType1,
        /// <summary>
        ///  IEC62196-2 Type 2 connector (captive cabled) a.k.a. Mennekes connector
        /// </summary>
        cType2,
        /// <summary>
        ///  16A 1 phase IEC60309 socket
        /// </summary>
        [JsonProperty("s309-1P-16A")]
        s309_1P_16A,
        /// <summary>
        ///  32A 1 phase IEC60309 socket
        /// </summary>
        [JsonProperty("s309-1P-32A")]
        s309_1P_32A,
        /// <summary>
        ///  16A 3 phase IEC60309 socket
        /// </summary>
        [JsonProperty("s309-3P-16A")]
        s309_3P_16A,
        /// <summary>
        ///  32A 3 phase IEC60309 socket
        /// </summary>
        [JsonProperty("s309-3P-32A")]
        s309_3P_32A,
        /// <summary>
        ///  UK domestic socket a.k.a. 13Amp
        /// </summary>
        sBS1361,
        /// <summary>
        ///  CEE 7/7 16A socket. May represent 7/4 & 7/5 a.k.a Schuko
        /// </summary>
        [JsonProperty("sCEE-7-7")]
        sCEE_7_7,
        /// <summary>
        ///  IEC62196-2 Type 2 socket a.k.a. Mennekes connector
        /// </summary>
        sType2,
        /// <summary>
        ///  IEC62196-2 Type 2 socket a.k.a. Scame
        /// </summary>
        sType3,
        /// <summary>
        ///  Other single phase (domestic) sockets not mentioned above, rated at no more than 16A. CEE7/17, AS3112,
        /// NEMA 5-15, NEMA 5-20, JISC8303, TIS166, SI 32, CPCS-CCC, SEV1011, etc.
        /// </summary>
        Other1PhMax16A,
        /// <summary>
        ///  Other single phase sockets not mentioned above (over 16A)
        /// </summary>
        Other1PhOver16A,
        /// <summary>
        ///  Other 3 phase sockets not mentioned above. NEMA14-30, NEMA14-50.
        /// </summary>
        Other3Ph,
        /// <summary>
        ///  Pantograph connector
        /// </summary>
        Pan,
        /// <summary>
        ///  Wireless inductively coupled connection (generic)
        /// </summary>
        wInductive,
        /// <summary>
        ///  Wireless resonant coupled connection (generic)
        /// </summary>
        wResonant,
        /// <summary>
        ///  Yet to be determined (e.g. before plugged in)
        /// </summary>
        Undetermined,
        /// <summary>
        ///  Unknown; not determinable
        /// </summary>
        Unknown
    }
}
